pub type Format = Vec<Insertable>;Expand description
A format is a sequence of insertables concatenated together.
Aliased Type
pub struct Format { /* private fields */ }pub type Format = Vec<Insertable>;A format is a sequence of insertables concatenated together.
pub struct Format { /* private fields */ }